@@ -1,7 +1,8 @@
 #include <stdio.h>
 #include <stdlib.h>
+#include <strings.h>
 
-static char * mkstr(char * s) { return strcpy(malloc(strlen(s)+1), s); }
+static char * mkstr(char * s) { return strcpy((char*)malloc(strlen(s)+1), s); }
 
 void f() { mkstr("asdfasdf"); }
 
