@@ -1,11 +1,14 @@
-extern void ccmalloc_check_for_integrity();
+#ifdef __cplusplus
+extern "C"
+#endif
+void ccmalloc_check_for_integrity();
 
 #include <stdlib.h>
 
 int
 main()
 {
-  char * a = malloc(100);
+  char * a = (char*) malloc(100);
   a[-5]='0';			/* this is exactly in the second
   				 * word below `a' on 32 bit machines
 				 */
